"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.WebGLContextService = void 0;

var _tslib = require("tslib");

var _g = require("@antv/g");

var _manaSyringe = require("mana-syringe");

var _util = require("@antv/util");

var _dom = require("./utils/dom");

var WebGLContextService =
/** @class */
function () {
  function WebGLContextService() {}

  WebGLContextService.prototype.init = function () {
    var container = this.canvasConfig.container; // create container

    this.$container = (0, _util.isString)(container) ? document.getElementById(container) : container;

    if (this.$container) {
      // create canvas
      var $canvas = document.createElement('canvas');
      this.$container.appendChild($canvas);

      if (!this.$container.style.position) {
        this.$container.style.position = 'relative';
      }

      this.$canvas = $canvas;
    }
  };

  WebGLContextService.prototype.getDomElement = function () {
    return this.$canvas;
  };

  WebGLContextService.prototype.getContext = function () {
    return this.context;
  };

  WebGLContextService.prototype.getBoundingClientRect = function () {
    var _a;

    return (_a = this.$container) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect();
  };

  WebGLContextService.prototype.destroy = function () {
    if (this.$container && this.$canvas && this.$canvas.parentNode) {
      this.$container.removeChild(this.$canvas);
    }
  };

  WebGLContextService.prototype.resize = function (width, height) {
    if (this.$canvas) {
      var dpr = this.getDPR(); // set canvas width & height

      this.$canvas.width = dpr * width;
      this.$canvas.height = dpr * height; // set CSS style width & height

      (0, _dom.setDOMSize)(this.$canvas, width, height);
    }
  };

  WebGLContextService.prototype.getDPR = function () {
    var dpr = window.devicePixelRatio || 1;
    dpr = dpr >= 1 ? Math.ceil(dpr) : 1;
    return dpr;
  };

  WebGLContextService.prototype.applyCursorStyle = function (cursor) {
    if (this.$container) {
      this.$container.style.cursor = cursor;
    }
  };

  (0, _tslib.__decorate)([(0, _manaSyringe.inject)(_g.CanvasConfig), (0, _tslib.__metadata)("design:type", Object)], WebGLContextService.prototype, "canvasConfig", void 0);
  WebGLContextService = (0, _tslib.__decorate)([(0, _manaSyringe.singleton)({
    token: _g.ContextService
  })], WebGLContextService);
  return WebGLContextService;
}();

exports.WebGLContextService = WebGLContextService;